@@ -4,8 +4,8 @@ use thiserror::Error;
 #[derive(Error, Debug)]
 pub enum RebuildOrderError {
     /// Given package is not present in database
-    #[error("package not found")]
-    PackageNotFound,
+    #[error("package `{0}` not found")]
+    PackageNotFound(String),
 
     /// Pacman database failed to initialize
     #[error("could not initialize pacman db: `{0}`")]
