@@ -22,7 +22,9 @@ fn find_package_anywhere<'a>(pkgname: &str, pacman: &'a alpm::Alpm) -> Result<&'
             return Ok(pkg);
         }
     }
-    Err(anyhow!(RebuildOrderError::PackageNotFound))
+    Err(anyhow!(RebuildOrderError::PackageNotFound(
+        pkgname.to_string()
+    )))
 }
 
 /// Retrieve a HashMap of all reverse dependencies.
